@@ -1,5 +1,3 @@
-# -*- coding: iso-8859-1 -*-
-
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 # Modified by dgranda
 
@@ -20,6 +18,11 @@
 import gobject
 import sys
 import logging
+import datetime
+import matplotlib
+
+import dateutil.parser
+from dateutil.tz import * # for tzutc()
 
 from SimpleGladeApp import *
 from popupmenu import PopupMenu
@@ -28,11 +31,15 @@ from aboutdialog import About
 from pytrainer.lib.date import Date
 from pytrainer.lib.system import checkConf
 from pytrainer.lib.xmlUtils import XMLParser
-
+from pytrainer.lib.gpx import Gpx
 from pytrainer.lib.unitsconversor import *
 
 class Main(SimpleGladeApp):
-	def __init__(self, data_path = None, parent = None, version = None):
+	def __init__(self, data_path = None, parent = None, version = None, gpxDir = None):
+		def url_hook(dialog, url):
+			pytrainer.lib.webUtils.open_url_in_browser(url)
+		# Available in PyGTK 2.6 and above
+		gtk.about_dialog_set_url_hook(url_hook)
 		self.version = version
 		self.parent = parent
 		self.data_path = data_path
@@ -43,14 +50,17 @@ class Main(SimpleGladeApp):
 
 		self.popup = PopupMenu(data_path,self)
 		self.block = False
+		self.activeSport = None
+		self.gpxDir = gpxDir
 
 	def new(self):
+		self.testimport = self.parent.testimport
 		self.menublocking = 0
 		self.selected_view="day"
 		self.window1.set_title ("pyTrainer %s" % self.version)
 		self.record_list = []
 		#create the columns for the listdayrecord
-		column_names=[_("id"),_("Sport"),_("Kilometer")]
+		column_names=[_("id"),_("Start"), _("Sport"),_("Kilometer")]
 		self.create_treeview(self.recordTreeView,column_names)
 		#create the columns for the listarea
 		column_names=[_("id"),_("Title"),_("Date"),_("Distance"),_("Sport"),_("Time"),_("Beats"),_("Average"),("Calories")]
@@ -65,6 +75,11 @@ class Main(SimpleGladeApp):
 			self._createXmlListView(self.fileconf)
 		self.showAllRecordTreeViewColumns()
 		self.allRecordTreeView.set_search_column(1)
+		self.notebook.set_current_page(1)
+
+		#Disable import menu item unless specified on startup
+		if not self.testimport:
+			self.menu_importdata.set_sensitive(0)
 	
 	def _createXmlListView(self,file):
 		menufile = XMLParser(file)
@@ -80,10 +95,16 @@ class Main(SimpleGladeApp):
 		savedOptions.append(("calories","False"))
 		menufile.createXMLFile("listviewmenu",savedOptions)	
 
+	def removeImportPlugin(self, plugin):
+		for widget in self.menuitem1_menu:
+			if widget.get_name() == plugin[1]:
+				self.menuitem1_menu.remove(widget)
+
 	def addImportPlugin(self,plugin):
 		button = gtk.MenuItem(plugin[0])
+		button.set_name(plugin[1])
 		button.connect("activate", self.parent.runPlugin, plugin[1])
-		self.menuitem1_menu.insert(button,2)
+		self.menuitem1_menu.insert(button,3)
 		self.menuitem1_menu.show_all()
 
 	def addExtension(self,extension):
@@ -100,26 +121,31 @@ class Main(SimpleGladeApp):
 			id = selected.get_value(iter,0)
 		self.parent.runExtension(extension,id)
 
-	def createGraphs(self,RecordGraph,DayGraph,MonthGraph,YearGraph,HeartRateGraph):
-		self.drawarearecord = RecordGraph(self.record_vbox, self.record_combovalue, self.record_combovalue2)
-		self.drawareaheartrate = HeartRateGraph(self.heartrate_vbox,self.heartrate_vbox2)
+	def createGraphs(self,RecordGraph,DayGraph,WeekGraph, MonthGraph,YearGraph,HeartRateGraph):
+		self.drawarearecord = RecordGraph(self.record_vbox, self.window1, self.record_combovalue, self.record_combovalue2, self.btnShowLaps)
+		self.drawareaheartrate = HeartRateGraph(self.heartrate_vbox, self.window1, self.heartrate_vbox2)
 		#self.drawareaday = DayGraph(self.day_vbox, self.day_combovalue)
 		self.day_vbox.hide()
-		self.drawareamonth = MonthGraph(self.month_vbox, self.month_combovalue,self.month_combovalue2)
-		self.drawareayear = YearGraph(self.year_vbox, self.year_combovalue,self.year_combovalue2)
+		self.drawareaweek = WeekGraph(self.weekview, self.window1, self.week_combovalue, self.week_combovalue2)
+		self.drawareamonth = MonthGraph(self.month_vbox, self.window1, self.month_combovalue,self.month_combovalue2)
+		self.drawareayear = YearGraph(self.year_vbox, self.window1, self.year_combovalue,self.year_combovalue2)
 	
-	def createMap(self,Googlemaps,waypoint):
-		self.googlemaps = Googlemaps(self.data_path, self.map_vbox,waypoint)
+	def createMap(self,Googlemaps,waypoint, useGM3):
+		self.googlemaps = Googlemaps(self.data_path, self.map_vbox,waypoint, useGM3)
 
-	def updateSportList(self,listSport):
+	def updateSportList(self,listSport): 
 		logging.debug(">>")
-		self.sportlist.set_active(1)
-		while (self.sportlist.get_active() == 1):
-			self.sportlist.remove_text(1)
-			self.sportlist.set_active(1)
+		liststore =  self.sportlist.get_model()
+		if self.sportlist.get_active() is not 0:
+			self.sportlist.set_active(0) #Set first item active if it isnt
+		firstEntry = self.sportlist.get_active_text()
+		liststore.clear() #Delete all items
+		#Re-add "All Sports"
+		liststore.append([firstEntry])
+		#Re-add all sports in listSport
 		for i in listSport:
-			self.sportlist.append_text(i[0])
-			self.sportlist.set_active(0)
+			liststore.append([i[0]])
+		self.sportlist.set_active(0)
 		logging.debug("<<")
 
 	def create_treeview(self,treeview,column_names):
@@ -171,6 +197,20 @@ class Main(SimpleGladeApp):
 			pace = self.parseFloat(record_list[14]) #to review
 			maxspeed = self.parseFloat(record_list[12]) #to review
 			maxpace = self.parseFloat(record_list[13])
+
+			#Get datetime from DB, use local time if available otherwise use date_time_utc and create a local datetime...
+			#TODO get data from date_time_local and parse 
+			date_time_local = record_list[17]
+			date_time_utc = record_list[16]
+			if date_time_local is not None: #Have a local time stored in DB
+				dateTime = dateutil.parser.parse(date_time_local)
+			else: #No local time in DB
+				tmpDateTime = dateutil.parser.parse(date_time_utc)
+				dateTime = tmpDateTime.astimezone(tzlocal()) #datetime with localtime offset (using value from OS)
+			recordDateTime = dateTime.strftime("%Y-%m-%d %H:%M:%S")
+			recordDate = dateTime.strftime("%x")
+			recordTime = dateTime.strftime("%X")
+			recordDateTimeOffset = dateTime.strftime("%z")
 			
 			if configuration.getValue("pytraining","prf_us_system") == "True":
 				self.record_distance.set_text("%0.2f" %km2miles(distance))
@@ -191,12 +231,16 @@ class Main(SimpleGladeApp):
 				self.record_maxpace.set_text("%0.2f" %maxpace)
 			
 			self.record_sport.set_text(sport)
-			self.record_date.set_text(str(date))
+			#self.record_date.set_text(str(date))
+			self.record_date.set_text(recordDate)
+			self.record_time.set_text(recordTime)
 			hour,min,sec=self.parent.date.second2time(int(record_list[3]))
 			self.record_hour.set_text("%d" %hour)
-			self.record_minute.set_text("%d" %min)
-			self.record_second.set_text("%d" %sec)
+			self.record_minute.set_text("%02d" %min)
+			self.record_second.set_text("%02d" %sec)
 			self.record_calories.set_text("%0.0f" %calories)
+			#self.record_datetime.set_text(recordDateTime)
+			#self.record_datetime_offset.set_text(recordDateTimeOffset)
 			self.record_title.set_text(title)
 			buffer = self.record_comments.get_buffer()
 			start,end = buffer.get_bounds()
@@ -205,21 +249,30 @@ class Main(SimpleGladeApp):
 		else:
 			self.recordview.set_sensitive(0)
 		logging.debug(">>")
-	
-	def actualize_recordgraph(self,record_list):
+
+	def actualize_recordgraph(self,record_list,laps=None):
 		logging.debug(">>")
 		if len(record_list)>0:
 			self.record_vbox.set_sensitive(1)
 		else:
+			#Remove graph
+			vboxChildren = self.record_vbox.get_children()
+			logging.debug('Vbox has %d children %s' % (len(vboxChildren), str(vboxChildren) ))
+			# ToDo: check why vertical container is shared
+			for child in vboxChildren:
+				#Remove all FigureCanvasGTK and NavigationToolbar2GTKAgg to stop double ups of graphs
+				if isinstance(child, matplotlib.backends.backend_gtkagg.FigureCanvasGTK) or isinstance(child, matplotlib.backends.backend_gtkagg.NavigationToolbar2GTKAgg):
+					logging.debug('Removing child: '+str(child))
+					self.record_vbox.remove(child)
 			self.record_vbox.set_sensitive(0)
 		#logging.debug("Going to draw "+str(record_list))
-		self.drawarearecord.drawgraph(record_list)
+		self.drawarearecord.drawgraph(record_list,laps)
 		logging.debug("<<")
 	
 	def actualize_heartrategraph(self,record_list):
 		logging.debug(">>")
 		self.drawareaheartrate.drawgraph(record_list)
-		logging.debug(">>")
+		logging.debug("<<")
 
 	def actualize_hrview(self,record_list,zones,is_karvonen_method):
 		logging.debug(">>")
@@ -268,6 +321,7 @@ class Main(SimpleGladeApp):
 			beats = 0
 			maxbeats = 0
 			maxspeed = 0
+			average = 0
 			maxpace = "0.00"
 			pace = "0.00"
 			for record in record_list:
@@ -288,8 +342,8 @@ class Main(SimpleGladeApp):
 			
 			if tbeats > 0:		
 				tbeats = tbeats/(timeinseconds/60/60)
-
-			average = distance/(timeinseconds/60/60)
+			if distance > 0:
+				average = distance/(timeinseconds/60/60)
 			if maxspeed > 0:
 				maxpace = "%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60)
 			if average > 0:
@@ -299,8 +353,8 @@ class Main(SimpleGladeApp):
 			self.day_distance.set_text("%0.2f" %distance)
 			hour,min,sec=self.parent.date.second2time(timeinseconds)
 			self.day_hour.set_text("%d" %hour)
-			self.day_minute.set_text("%d" %min)
-			self.day_second.set_text("%d" %sec)
+			self.day_minute.set_text("%02d" %min)
+			self.day_second.set_text("%02d" %sec)
 			self.day_beats.set_text("%0.2f" %tbeats)
 			self.day_maxbeats.set_text("%0.2f" %maxbeats)
 			self.day_average.set_text("%0.2f" %average)
@@ -328,6 +382,88 @@ class Main(SimpleGladeApp):
 		self.googlemaps.drawMap(id_record)
 		logging.debug("<<")
 	
+	def actualize_weekview(self, record_list, date_ini, date_end):
+		logging.debug(">>")
+		date_s = datetime.datetime.strptime(date_ini, "%Y-%m-%d")
+		date_e = datetime.datetime.strptime(date_end, "%Y-%m-%d")
+		self.week_date.set_text("%s - %s (%d)" % (datetime.datetime.strftime(date_s, "%a %d %b"), datetime.datetime.strftime(date_e, "%a %d %b"), int(datetime.datetime.strftime(date_e, "%W"))+1) )
+
+		km = calories = time = average = beats = 0
+		num_records = len(record_list)
+		logging.info("Number of records selected week: "+str(num_records))
+		time_in_min = 0
+		tbeats = 0
+		maxspeed = 0
+		pace = "0.00"
+		maxpace = "0.00"
+		maxbeats = 0
+		
+		conf = checkConf()
+		filename = conf.getValue("conffile")
+		configuration = XMLParser(filename)
+		if configuration.getValue("pytraining","prf_us_system") == "True":
+			self.w_distance_unit.set_text(_("miles"))
+			self.w_speed_unit.set_text(_("miles/h"))
+			self.w_maxspeed_unit.set_text(_("miles/h"))
+			self.w_pace_unit.set_text(_("min/mile"))
+			self.w_maxpace_unit.set_text(_("min/mile"))
+		else:
+			self.w_distance_unit.set_text(_("km"))
+			self.w_speed_unit.set_text(_("km/h"))
+			self.w_maxspeed_unit.set_text(_("km/h"))
+			self.w_pace_unit.set_text(_("min/km"))
+			self.w_maxpace_unit.set_text(_("min/km"))
+
+		if num_records>0:
+			for record in record_list:
+				km += self.parseFloat(record[1])
+				time += self.parseFloat(record[2])
+				average += self.parseFloat(record[5])
+				calories += self.parseFloat(record[6])
+				beats = self.parseFloat(record[3])
+				if float(beats) > 0:
+					time_in_min += time/60
+					tbeats += beats*(time/60)
+				if record[7] > maxspeed:
+					maxspeed = self.parseFloat(record[7])
+				if record[8] > maxbeats:
+					maxbeats = self.parseFloat(record[8])
+			
+			if configuration.getValue("pytraining","prf_us_system") == "True":
+				km = km2miles(km)
+				maxspeed = km2miles(maxspeed)
+			
+			if time_in_min > 0:
+				tbeats = tbeats/time_in_min		
+			else:
+				tbeats = 0
+			average = (km/(time/3600))
+		
+			if maxspeed > 0:
+				#maxpace = 60/maxspeed
+				maxpace = "%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60)
+			if average > 0:
+				#pace = 60/average
+				pace = "%d.%02d" %((3600/average)/60,(3600/average)%60)
+		
+			self.weeka_distance.set_text("%0.2f" %km)
+			hour,min,sec = self.parent.date.second2time(time)
+			self.weeka_hour.set_text("%d" %hour)
+			self.weeka_minute.set_text("%02d" %min)
+			self.weeka_second.set_text("%02d" %sec)
+			self.weeka_maxbeats.set_text("%0.2f" %(maxbeats))
+			self.weeka_beats.set_text("%0.2f" %(tbeats))
+			self.weeka_average.set_text("%0.2f" %average)
+			self.weeka_maxspeed.set_text("%0.2f" %maxspeed)
+			self.weeka_pace.set_text(pace)
+			self.weeka_maxpace.set_text(maxpace)
+			self.weeka_calories.set_text("%0.0f" %calories)
+			self.weekview.set_sensitive(1)
+		else:
+			self.weekview.set_sensitive(0)
+		self.drawareaweek.drawgraph(record_list, date_ini, date_end)
+		logging.debug("<<")
+
 	def actualize_monthview(self,record_list, nameMonth):
 		logging.debug(">>")
 		self.month_date.set_text(nameMonth)
@@ -391,8 +527,8 @@ class Main(SimpleGladeApp):
 			self.montha_distance.set_text("%0.2f" %km)
 			hour,min,sec = self.parent.date.second2time(time)
 			self.montha_hour.set_text("%d" %hour)
-			self.montha_minute.set_text("%d" %min)
-			self.montha_second.set_text("%d" %sec)
+			self.montha_minute.set_text("%02d" %min)
+			self.montha_second.set_text("%02d" %sec)
 			self.montha_maxbeats.set_text("%0.2f" %(maxbeats))
 			self.montha_beats.set_text("%0.2f" %(tbeats))
 			self.montha_average.set_text("%0.2f" %average)
@@ -405,9 +541,9 @@ class Main(SimpleGladeApp):
 			self.monthview.set_sensitive(0)
 		logging.debug("<<")
 
-	def actualize_monthgraph(self,record_list):
+	def actualize_monthgraph(self,record_list, daysInMonth):
 		logging.debug(">>")
-		self.drawareamonth.drawgraph(record_list)
+		self.drawareamonth.drawgraph(record_list, daysInMonth)
 		logging.debug("<<")
 	
 	def actualize_yearview(self,record_list, year):
@@ -451,8 +587,8 @@ class Main(SimpleGladeApp):
 			self.yeara_distance.set_text("%0.2f" %km)
 			hour,min,sec = self.parent.date.second2time(time)
 			self.yeara_hour.set_text("%d" %hour)
-			self.yeara_minute.set_text("%d" %min)
-			self.yeara_second.set_text("%d" %sec)
+			self.yeara_minute.set_text("%02d" %min)
+			self.yeara_second.set_text("%02d" %sec)
 			self.yeara_beats.set_text("%0.2f" %tbeats)
 			self.yeara_maxbeats.set_text("%0.2f" %(maxbeats))
 			self.yeara_average.set_text("%0.2f" %average)
@@ -654,12 +790,12 @@ class Main(SimpleGladeApp):
 	######################
 
 	def on_edit_clicked(self,widget):
-    		selected,iter = self.recordTreeView.get_selection().get_selected()
+		selected,iter = self.recordTreeView.get_selection().get_selected()
 		id_record = selected.get_value(iter,0)
 		self.parent.editRecord(id_record)
 
 	def on_remove_clicked(self,widget):
-    		selected,iter = self.recordTreeView.get_selection().get_selected()
+		selected,iter = self.recordTreeView.get_selection().get_selected()
 		id_record = selected.get_value(iter,0)
 		self.parent.removeRecord(id_record)
 	
@@ -677,7 +813,11 @@ class Main(SimpleGladeApp):
 	
 	def on_sportlist_changed(self,widget):
 		logging.debug("--")
-		self.parent.refreshGraphView(self.selected_view)
+		if self.sportlist.get_active() != self.activeSport:
+			self.activeSport = self.sportlist.get_active()
+			self.parent.refreshGraphView(self.selected_view)
+		else:
+			logging.debug("on_sportlist_changed called with no change")
 	
 	def on_page_change(self,widget,gpointer,page):
 		logging.debug("--")
@@ -686,8 +826,10 @@ class Main(SimpleGladeApp):
 		elif page == 1:
 			self.selected_view="day"
 		elif page == 2:
-			self.selected_view="month"
+			self.selected_view="week"
 		elif page == 3:
+			self.selected_view="month"
+		elif page == 4:
 			self.selected_view="year"
 		self.parent.refreshGraphView(self.selected_view)
 	
@@ -710,11 +852,19 @@ class Main(SimpleGladeApp):
 	def on_hidemap_clicked(self,widget):
 		self.maparea.hide()
 		self.infoarea.show()
+
+	def on_btnShowLaps_toggled(self,widget):
+		logging.debug("--")
+		self.parent.refreshGraphView(self.selected_view)
 	
 	def on_day_combovalue_changed(self,widget):
 		logging.debug("--")
 		self.parent.refreshGraphView(self.selected_view)
 	
+	def on_week_combovalue_changed(self,widget):
+		logging.debug("--")
+		self.parent.refreshGraphView(self.selected_view)
+
 	def on_month_combovalue_changed(self,widget):
 		logging.debug("--")
 		self.parent.refreshGraphView(self.selected_view)
@@ -728,15 +878,16 @@ class Main(SimpleGladeApp):
 		if self.block:
 			self.block = False
 		else:
-			self.notebook.set_current_page(1)
-			self.selected_view="day"
 			self.parent.refreshListRecords()
 			self.parent.refreshGraphView(self.selected_view)
+			if self.selected_view == "record":
+				self.recordview.set_current_page(0)
+				self.parent.refreshRecordGraphView("info")
 
 	def on_calendar_changemonth(self,widget):
 		logging.debug("--")
 		self.block = True
-		self.notebook.set_current_page(2)
+		self.notebook.set_current_page(3)
 		self.selected_view="month"
 		self.parent.refreshListRecords()
 		self.parent.refreshGraphView(self.selected_view)
@@ -744,7 +895,7 @@ class Main(SimpleGladeApp):
 	def on_calendar_next_year(self,widget):
 		logging.debug("--")
 		self.block = True
-		self.notebook.set_current_page(3)
+		self.notebook.set_current_page(4)
 		self.selected_view="year"
 		self.parent.refreshListRecords()
 		self.parent.refreshGraphView(self.selected_view)
@@ -765,6 +916,9 @@ class Main(SimpleGladeApp):
 		self.classicarea.hide()
 		self.parent.refreshWaypointView()
 		self.waypointarea.show()
+
+	def on_menu_importdata_activate(self,widget):
+		self.parent.importData()
 	
 	def on_extensions_activate(self,widget):
 		self.parent.editExtensions()
@@ -774,7 +928,7 @@ class Main(SimpleGladeApp):
 	#hasta aqui revisado
 	def on_allRecordTreeView_button_press(self, treeview, event):
 		logging.debug(">>")
-		print "on_allRecordTreeView_"
+		#print "on_allRecordTreeView_"
 		x = int(event.x)
 		y = int(event.y)
 		time = event.time
@@ -797,28 +951,93 @@ class Main(SimpleGladeApp):
 		logging.debug("<<")
 		return False
 	
-	def actualize_recordTreeView(self, record_list):
+	'''def actualize_recordTreeView(self, record_list):
 		logging.debug(">>")
 		iterOne = False
 		store = gtk.ListStore(
 			gobject.TYPE_INT,
 			gobject.TYPE_STRING,
 			gobject.TYPE_STRING,
+			gobject.TYPE_STRING,
 			object)
 		for i in record_list:
 			iter = store.append()
 			if not iterOne:
 				iterOne = iter
+			dateTime = i[12]
+			if dateTime is not None:
+				localTime = dateutil.parser.parse(dateTime).strftime("%H:%M")
+			else:
+				localTime = ""
 			store.set (
 				iter,
 				0, int(i[8]),
-				1, str(i[0]),
-				2, str(i[2])
+				1, str(localTime),
+				2, str(i[0]),
+				3, str(i[2])
 				)
 		self.recordTreeView.set_model(store)
 		if iterOne:
 			self.recordTreeView.get_selection().select_iter(iterOne)
 		logging.debug("<<")
+		#if len(record_list)>0:'''
+
+	def actualize_recordTreeView(self, record_list):
+		logging.debug(">>")
+		iterOne = False
+		store = gtk.TreeStore(
+			gobject.TYPE_INT,          	#record_id
+			gobject.TYPE_STRING,		#Time
+			gobject.TYPE_STRING,		#Sport
+			gobject.TYPE_STRING,		#Distance
+			object)
+		for i in record_list:
+			#Get lap info #TODO refactor to use a database table
+			gpxfile =  "%s/%s.gpx" %(self.gpxDir, i[8])
+			laps = None
+			if os.path.isfile(gpxfile):
+				gpx = Gpx(self.data_path,gpxfile)
+				laps = gpx.getLaps() #(elapsedTime, lat, lon, calories, distance)
+			#print gpxfile, laps
+			iter = store.append(None)
+			if not iterOne:
+				iterOne = iter
+			dateTime = i[12]
+			if dateTime is not None:
+				localTime = dateutil.parser.parse(dateTime).strftime("%H:%M")
+			else:
+				localTime = ""
+			store.set (
+				iter,
+				0, int(i[8]),
+				1, str(localTime),
+				2, str(i[0]),
+				3, str(i[2])
+				)
+			if laps is not None:
+				for lap in laps:
+					lapNumber = "%s%d" % ( _("lap"), (laps.index(lap)+1) )
+					distance = "%0.2f" % (float(lap[4]) / 1000.0)
+					timeHours = int(float(lap[0]) / 3600)
+					timeMin = int((float(lap[0]) / 3600.0 - timeHours) * 60)
+					timeSec = float(lap[0]) - (timeHours * 3600) - (timeMin * 60) 
+					if timeHours > 0:
+						duration = "%d%s%02d%s%02d%s" % (timeHours, _("h"), timeMin, _("m"), timeSec, _("s"))
+					else:
+						duration = "%2d%s%02d%s" % (timeMin, _("m"), timeSec, _("s"))
+
+					child_iter = store.append(iter)
+					store.set (
+						child_iter,
+						0, int(i[8]),
+						1, lapNumber,
+						2, duration,
+						3, distance
+						)
+		self.recordTreeView.set_model(store)
+		if iterOne:
+			self.recordTreeView.get_selection().select_iter(iterOne)
+		logging.debug("<<")
 		#if len(record_list)>0:
 	
 	def parseFloat(self,string):
@@ -843,7 +1062,7 @@ class Main(SimpleGladeApp):
 		if (sport > 0):
 			return self.sportlist.get_active_text()
 		else:
-			return -1
+			return None
 
 	def quit(self, *args):
 		self.parent.quit()
