@@ -25,6 +25,7 @@ import gobject
 pygtk.require('2.0')
 import gtk
 import gtk.glade
+from optparse import OptionParser
 import logging
 import logging.handlers
 import traceback
@@ -34,10 +35,12 @@ from os import path
 from record import Record
 from waypoint import Waypoint
 from extension import Extension
+from importdata import Importdata
 from plugins import Plugins
 from profile import Profile
 from recordgraph import RecordGraph
 from daygraph import DayGraph
+from weekgraph import WeekGraph
 from monthgraph import MonthGraph
 from yeargraph import YearGraph
 from heartrategraph import HeartRateGraph
@@ -46,9 +49,9 @@ from extensions.googlemaps import Googlemaps
 from extensions.waypointeditor import WaypointEditor
 
 #from gui.windowextensions import WindowExtensions
+from gui.windowimportdata import WindowImportdata
 from gui.windowmain import Main
 from gui.warning import Warning
-from lib.system import checkConf
 from lib.date import Date
 from lib.gpx import Gpx
 from lib.soapUtils import webService
@@ -57,23 +60,35 @@ from lib.xmlUtils import XMLParser
 from lib.system import checkConf
 from lib.heartrate import *
 
-# 21.03.2008 - dgranda (updated 17.04.2008)
-# Only one parameter from command line is accepted
+
+##TODO The below should all be able to be in the __init__ section, i.e. does not need to be global 
+
 # ERROR is the default log level
-log_level = logging.ERROR
 PATH = os.environ['HOME']+"/.pytrainer"
 if not os.path.exists(PATH):
 	os.mkdir(PATH)
 LOG_FILENAME = PATH + "/log.out"
-if len(sys.argv) > 1:
-	if sys.argv[1]=='-d':
-		log_level = logging.DEBUG
-	elif sys.argv[1]=='-i':
-		log_level = logging.INFO
-	elif sys.argv[1]=='-w':
-		log_level = logging.WARNING
-	else:
-		print "CLI - Unknown parameter "+sys.argv[1]
+
+#Setup usage and permitted options
+usage = """usage: %prog [options]
+
+For more help on valid options try:
+   %prog -h """
+parser = OptionParser(usage=usage)
+parser.set_defaults(log_level=logging.ERROR, validate=False, gm3=True, testimport=False)
+parser.add_option("-d", "--debug", action="store_const", const=logging.DEBUG, dest="log_level", help="enable logging at debug level")
+parser.add_option("-i", "--info", action="store_const", const=logging.INFO, dest="log_level", help="enable logging at info level")
+parser.add_option("-w", "--warn", action="store_const", const=logging.WARNING, dest="log_level", help="enable logging at warning level")
+parser.add_option("--valid", action="store_true", dest="validate", help="enable validation of files imported by plugins (details at info or debug logging level) - note plugin must support validation")
+parser.add_option("--check", action="store_true", dest="check", help="triggers database (only sqlite based) and configuration file sanity checks, adding fields if necessary. Backup of database is done before any change. Details at info or debug logging level")
+parser.add_option("--gmaps2", action="store_false", dest="gm3", help="Use old Google Maps API version (v2)")
+parser.add_option("--testimport", action="store_true", dest="testimport", help="EXPERIMENTAL: show new import functionality - for testing only USE AT YOUR OWN RISK")
+(options, args) = parser.parse_args()
+log_level = options.log_level
+validate = options.validate
+check = options.check
+gm3 = options.gm3
+testimport = options.testimport
 
 # Adding rotating support to default logger with customized format
 rotHandler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=100000, backupCount=5)
@@ -86,42 +101,69 @@ class pyTrainer:
 	def __init__(self,filename = None, data_path = None): 
 		logging.debug('>>')
 		self.data_path = data_path
-		self.version ="1.6.0.8" # 19.04.2009
+		self.version ="1.7.1"
+		self.DB_version = 1
 		self.date = Date()
-
 		# Checking profile
 		self.profile = Profile(self.data_path,self)
-		#self.profile.setVersion("0.0")
 		self.profile.isProfileConfigured()
+		#Populate startup options
+		self.log_level = log_level
+		self.validate = validate
+		self.check = check
+		self.gm3 = gm3
+		self.testimport = testimport
+
+		self.windowmain = None
 
 		logging.debug('checking configuration...')
-		self.conf = checkConf()
+		self.conf = checkConf() #TODO set this up so other modules can reference this and not have to duplicate this
+		logging.debug("clearing tmp directory %s" % self.conf.getValue("tmpdir"))
+		self.conf.clearTempDir()
 		self.filename = self.conf.getValue("conffile")
 		logging.debug('retrieving data from '+ self.filename)
-		self.configuration = XMLParser(self.filename)
-		self.ddbb = DDBB(self.configuration)
+		self.configuration = XMLParser(self.filename) #TODO set this up so other modules can reference this and not have to duplicate this
+		if self.configuration.getValue("pytraining","prf_us_system") == "True":
+			self.prf_us_system = True
+		else:
+			self.prf_us_system = False
+		self.ddbb = DDBB(self.configuration) #TODO set this up so other modules can reference this and not have to duplicate this
 		logging.debug('connecting to DDBB')
 		self.ddbb.connect()		
+
+		#Get user's DB version
+		currentDB_version = self.configuration.getValue("pytraining","DB_version")
+		logging.debug("Current DB version: "+str(currentDB_version))
+		# DB check can be triggered either via new version (mandatory) or as runtime parameter (--check)		
+		if self.check: # User requested check
+			self.sanityCheck() 
+		elif currentDB_version is None: # No stored DB version - check DB etc
+			self.sanityCheck() 
+		elif self.DB_version > int(currentDB_version): # DB version expected is newer than user's version - check DB etc
+			self.sanityCheck() 
+		else:
+			logging.info('No sanity check requested')
+
 		self.record = Record(data_path,self)
-		
-		self.migrationCheck()
-		
+
 		#preparamos la ventana principal
-		self.windowmain = Main(data_path,self,self.version)
+		self.windowmain = Main(data_path,self,self.version, gpxDir=self.conf.getValue("gpxdir"))
 		self.date = Date(self.windowmain.calendar)
 
 		#Preparamos el webservice	 
+		#TODO check reason for webservice - remove / change to optional start if not needed
 		gtk.gdk.threads_init()
 		self.webservice = webService(data_path,self.refreshWaypointView,self.newRecord)
 		self.webservice.start()
 
 		self.waypoint = Waypoint(data_path,self)
 		self.extension = Extension(data_path)
-		self.plugins = Plugins(data_path)
+		self.plugins = Plugins(data_path, self)
+		self.importdata = Importdata(data_path, self, self.configuration)
 		self.loadPlugins()
 		self.loadExtensions()
-		self.windowmain.createGraphs(RecordGraph,DayGraph,MonthGraph,YearGraph,HeartRateGraph)
-		self.windowmain.createMap(Googlemaps,self.waypoint)
+		self.windowmain.createGraphs(RecordGraph,DayGraph,WeekGraph, MonthGraph,YearGraph,HeartRateGraph)
+		self.windowmain.createMap(Googlemaps,self.waypoint, self.gm3)
 		self.windowmain.createWaypointEditor(WaypointEditor,self.waypoint)
 		self.windowmain.on_calendar_selected(None)
 		self.refreshMainSportList()	 
@@ -160,12 +202,21 @@ class pyTrainer:
 
 	def runPlugin(self,widget,pathPlugin):
 		logging.debug('>>')
-		gtrnctrFile = self.plugins.runPlugin(pathPlugin)
-		if os.path.isfile(gtrnctrFile):
-			logging.info('File exists. Size: '+ str(os.path.getsize(gtrnctrFile)))
- 			self.record.importFromGTRNCTR(gtrnctrFile)
- 		else:
- 			logging.error('File '+gtrnctrFile+' not valid')
+		self.pluginClass = self.plugins.importClass(pathPlugin)
+		pluginFiles = self.pluginClass.run()
+		if pluginFiles is not None:
+			logging.debug("Plugin returned %d files" % (len(pluginFiles)) )	
+			#process returned GPX files	
+			for (pluginFile, sport) in pluginFiles:
+				if os.path.isfile(pluginFile):
+					logging.info('File exists. Size: %d. Sport: %s' % (os.path.getsize(pluginFile), sport))
+					self.record.importFromGPX(pluginFile, sport)
+ 				else:
+ 					logging.error('File '+pluginFile+' not valid')
+		else:
+			logging.debug("No files returned from Plugin")
+		self.refreshListRecords()
+		self.refreshGraphView("day")
 		logging.debug('<<')
 
 	def runExtension(self,extension,id):
@@ -184,6 +235,10 @@ class pyTrainer:
 		
 	def refreshGraphView(self, view, sport=None):
 		logging.debug('>>')
+		if self.windowmain is None:
+			logging.debug("First call to refreshGraphView")
+			logging.debug('<<')
+			return
 		date_selected = self.date.getDate()
 		if view=="record":
 			 logging.debug('record view')
@@ -200,15 +255,21 @@ class pyTrainer:
 			 record_list = self.record.getrecordList(date_selected)
 			 self.windowmain.actualize_dayview(record_list)
 			 selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
+		elif view=="week":
+			 logging.debug('week view')
+			 date_ini, date_end = self.date.getWeekInterval(date_selected, self.prf_us_system)
+			 sport = self.windowmain.getSportSelected()
+			 record_list = self.record.getrecordPeriod(date_ini, date_end, sport)
+			 self.windowmain.actualize_weekview(record_list, date_ini, date_end)
 		elif view=="month":
 			 logging.debug('month view')
 			 date_ini, date_end = self.date.getMonthInterval(date_selected)
 			 sport = self.windowmain.getSportSelected()
 			 record_list = self.record.getrecordPeriodSport(date_ini, date_end,sport)
 			 #logging.debug('record list: '+record_list)
-			 nameMonth = self.date.getNameMonth(date_selected)
+			 nameMonth, daysInMonth = self.date.getNameMonth(date_selected)
 			 self.windowmain.actualize_monthview(record_list, nameMonth)
-			 self.windowmain.actualize_monthgraph(record_list)
+			 self.windowmain.actualize_monthgraph(record_list, daysInMonth)
 		elif view=="year":
 			 logging.debug('year view')
 			 date_ini, date_end = self.date.getYearInterval(date_selected)
@@ -217,10 +278,13 @@ class pyTrainer:
 			 record_list = self.record.getrecordPeriodSport(date_ini, date_end,sport)
 			 self.windowmain.actualize_yearview(record_list, year)
 			 self.windowmain.actualize_yeargraph(record_list)
+		else:
+			print "Unknown view %s" % view
 		logging.debug('<<')
 	 
 	def refreshRecordGraphView(self, view):
 		logging.debug('>>')
+		logging.info('Working on '+view+' graph')
 		if view=="info":
 			 selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
 			 record_list=[]
@@ -236,9 +300,10 @@ class pyTrainer:
 				id_record = selected.get_value(iter,0)
 				gpxfile = self.conf.getValue("gpxdir")+"/%s.gpx" %id_record
 				if os.path.isfile(gpxfile):
-					 gpx = Gpx(self.data_path,gpxfile)
-					 gpx_tracklist = gpx.getTrackList()
-			 self.windowmain.actualize_recordgraph(gpx_tracklist)
+					gpx = Gpx(self.data_path,gpxfile)
+					gpx_tracklist = gpx.getTrackList()
+					gpx_laps = gpx.getLaps()
+			 self.windowmain.actualize_recordgraph(gpx_tracklist, gpx_laps)
 
 		if view=="map":
 			 self.refreshMapView()
@@ -301,10 +366,29 @@ class pyTrainer:
 		logging.debug('>>')
 		self.extension.manageExtensions()
 		logging.debug('<<')
+
+	def importData(self):
+		logging.debug('>>')
+		self.importdata.runImportdata()
+		logging.debug('<<')		
 		
 	def editGpsPlugins(self):
 		logging.debug('>>')
+		activeplugins_before = self.plugins.getActivePlugins()
 		self.plugins.managePlugins()
+		activeplugins_after = self.plugins.getActivePlugins()
+		#Need to check for plugins that have been disabled (were active and now are not)
+		for plugin in activeplugins_before:
+			if plugin not in activeplugins_after:
+				#disabled plugin -> need to unload plugin
+				txtbutton = self.plugins.loadPlugin(plugin)
+				self.windowmain.removeImportPlugin(txtbutton)
+		#Need to check for plugins that have been enabled (were not active and now are)
+		for plugin in activeplugins_after:
+			if plugin not in activeplugins_before:
+				#new active plugin -> need to load plugin
+				txtbutton = self.plugins.loadPlugin(plugin)
+				self.windowmain.addImportPlugin(txtbutton)
 		logging.debug('<<')
 
 	def newRecord(self,title=None,distance=None,time=None,upositive=None,unegative=None,bpm=None,calories=None,date=None,comment=None):
@@ -313,6 +397,7 @@ class pyTrainer:
 		if date == None:
 			 date = self.date.getDate()
 			 self.record.newRecord(list_sport, date, title, distance, time, upositive, unegative, bpm, calories, comment)
+		self.refreshListRecords()
 		logging.debug('<<')
 
 	def editRecord(self, id_record):
@@ -320,6 +405,7 @@ class pyTrainer:
 		list_sport = self.profile.getSportList()
 		logging.debug('id_record: '+str(id_record)+' | list_sport: '+str(list_sport))
 		self.record.editRecord(id_record,list_sport)
+		self.refreshListRecords()
 		logging.debug('<<')
 
 	def removeRecord(self, id_record, confirm = False):
@@ -332,6 +418,7 @@ class pyTrainer:
 			 warning = Warning(self.data_path,self.removeRecord,params)
 			 warning.set_text(msg)
 			 warning.run()
+		self.refreshListRecords()
 		logging.debug('<<')
 	 
 	def removeWaypoint(self,id_waypoint, confirm = False):
@@ -364,56 +451,27 @@ class pyTrainer:
 		logging.debug('>>')
 		self.profile.editProfile()
 		logging.debug('<<')
-		
-	def migrationCheck(self):
-		"""22.06.2008 - dgranda (reviewed 31.07.2008)
-		Checks if it is necessary to run migration scripts for new features
+
+	def sanityCheck(self):
+		"""23.11.2009 - dgranda
+		Checks database and configuration file 
 		args: none
 		returns: none"""
 		logging.debug('>>')
-		self.filename = self.conf.getValue("conffile")
-		logging.debug('Retrieving data from '+ self.filename)
-		version_tmp = self.configuration.getOption("version")
-		logging.info('Old version: '+version_tmp+' | New version: '+self.version)
-		if version_tmp == "0.0":
-			logging.info('Nothing to do, first installation')
-		else:
-			if version_tmp=="1.0":
-				logging.debug('updating month data')
-				self.ddbb.updatemonth()
-			if version_tmp<="0.9.8":
-				logging.debug('updating date format')
-				self.ddbb.updateDateFormat()
-			if version_tmp<="0.9.8.2":
-				logging.debug('updating DB title')
-				self.ddbb.addTitle2ddbb()
-			if version_tmp<="1.3.1":
-				self.ddbb.addUnevenness2ddbb()
-			if version_tmp<="1.4.2":
-				self.ddbb.addWaypoints2ddbb()
-			if version_tmp<="1.5.0.1":
-				self.ddbb.addweightandmet2ddbb()
-			if version_tmp<="1.5.0.2":
-				logging.info('Adding maxspeed, maxpace, pace and maxbeats columns')
-				self.ddbb.addpaceandmax2ddbb()
-			if version_tmp < "1.6.0.1":
-				logging.info('Adding date_time_utc column and retrieving data from local GPX files')
-				self.addDateTimeUTC()
-			if version_tmp < "1.6.0.3":
-				logging.info('Checking pace and max pace stored in DB')
-				self.checkPacesDB()
-				logging.info('Checking configuration file integrity')
-				self.profile.checkProfile()
-		if version_tmp < self.version:
-			self.configuration.setVersion(self.version)
+		logging.info('Checking database integrity')
+		self.ddbb.checkDBIntegrity()
+		logging.info('Checking configuration file integrity')
+		self.profile.checkProfile()
+		logging.info('Setting DB version to: ' + str(self.DB_version))
+		self.configuration.setValue("pytraining","DB_version", str(self.DB_version))
 		logging.debug('<<')
 	
-	def addDateTimeUTC(self):
+	#def addDateTimeUTC(self): #TODO remove
 		"""12.07.2008 - dgranda
 		Adds date_time (UTC format) for each record (new column date_time_utc in table records). New in version 1.6.0.1
 		args: none
 		returns: none"""
-		logging.debug('>>')
+		'''logging.debug('>>')
 		# Retrieves info from all GPX files stored locally
 		listTracksGPX = self.record.shortFromLocal()
 		logging.debug('Retrieved info from local files: '+ str(listTracksGPX))
@@ -435,14 +493,14 @@ class pyTrainer:
 				logging.error('Error when updating data for track '+ track[2])
 				traceback.print_exc()
 		logging.info('Updated '+str(num)+' entries')
-		logging.debug('<<')
+		logging.debug('<<')'''
 		
-	def checkPacesDB(self):
+	#def checkPacesDB(self): #TODO remove
 		"""19.07.2008 - dgranda
 		Updates paces in DB (maxspeed<->maxpace | average<->pace). New in version 1.6.0.2
 		args: none
 		returns: none"""
-		logging.debug('>>')
+		'''logging.debug('>>')
 		# Retrieves info from DB: id_record,maxspeed,maxpace,average,pace
 		listPaces = self.ddbb.select("records", "id_record,maxspeed,maxpace,average,pace")
 		logging.debug('Retrieved info from db: '+ str(listPaces))
@@ -460,4 +518,4 @@ class pyTrainer:
 			else:
 				logging.error('No pace info available for entry '+str(entry[0])+' in DB. Please check')
 		logging.info('Updated '+str(num)+' entries')
-		logging.debug('<<')
+		logging.debug('<<')'''
