@@ -38,13 +38,13 @@ class Record:
 		logging.debug('setting date...')
 		self.date = Date()
 		logging.debug('Checking current configuration...')
-		self.conf = checkConf()
-		self.filename = self.conf.getValue("conffile")
-		logging.debug('Retrieving data from '+ self.filename)
-		self.configuration = XMLParser(self.filename)
-		self.ddbb = DDBB(self.configuration)
-		logging.debug('connecting to DDBB')
-		self.ddbb.connect()
+		self.conf = checkConf()									#TODO change to reference main versions of these
+		self.filename = self.conf.getValue("conffile")			#
+		logging.debug('Retrieving data from '+ self.filename)	#
+		self.configuration = XMLParser(self.filename)			#
+		self.ddbb = DDBB(self.configuration)					#
+		logging.debug('connecting to DDBB')						#
+		self.ddbb.connect()										#
 		logging.debug('<<')
 
 	def newRecord(self, list_sport, date, title=None, distance=None, time=None, upositive=None, unegative=None, bpm=None, calories=None, comment=None):
@@ -58,16 +58,18 @@ class Record:
 		logging.debug('retrieving data from DB: '+str(record))
 		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
 		logging.debug('gpx file associated: '+gpxfile)
-		self.recordwindow = WindowRecord(self.data_path, list_sport,self, None)
+		self.recordwindow = WindowRecord(self.data_path, list_sport,self, None, windowTitle=_("Edit Entry"))
 		if os.path.isfile(gpxfile):
 			self.recordwindow.rcd_gpxfile.set_text(gpxfile)
+			self.recordwindow.frameGeneral.set_sensitive(0)		#Currently record values not changed if a GPX file is present
+			self.recordwindow.frameVelocity.set_sensitive(0)	#Greying out options to indicate this to user
 		logging.debug('sending record info to window')
 		self.recordwindow.setValues(record[0])
 		logging.debug('launching window')
 		self.recordwindow.run()
 		logging.debug('<<')
 	
-	def removeRecord(self,id_record):
+	def removeRecord(self,id_record): #TODO remember to update once laps are in DB
 		logging.debug('>>')
 		record = self.ddbb.delete("records", "id_record=\"%s\"" %id_record)
 		logging.debug('removed record '+str(id_record)+' from bbdd')
@@ -116,12 +118,12 @@ class Record:
 		logging.debug('>>')
 		time = self.date.time2second(list_options["rcd_time"])
 		average = self.parseFloatRecord(list_options["rcd_average"])
-		keys= "date,sport,distance,time,beats,comments,average,calories,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc"
+		keys= "date,sport,distance,time,beats,comments,average,calories,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local"
 		if (list_options["rcd_beats"] == ""):
 			list_options["rcd_beats"] = 0
 		
 		#retrieving sport id (adding sport if it doesn't exist yet)
-		sport_id = self.getSportId(list_options["rcd_sport"],add=None)
+		sport_id = self.getSportId(list_options["rcd_sport"],add=True)
 
 		values= (
 			list_options["rcd_date"],
@@ -140,27 +142,35 @@ class Record:
 			self.parseFloatRecord(list_options["rcd_pace"]),
 			self.parseFloatRecord(list_options["rcd_maxbeats"]),
 			list_options["date_time_utc"],
+			list_options["date_time_local"],
 			)
 		logging.debug('<<')
 		return keys,values
 
 	def insertRecord(self, list_options):
 		logging.debug('>>')
+		if list_options is None:
+			logging.debug('No data provided, abort adding entry')
+			return None
+		elif list_options["rcd_time"] == [0, 0, 0]:
+			logging.debug('Activity has no duration, abort adding entry')
+			return None
 		logging.debug('list_options: '+str(list_options))
 		cells,values = self._formatRecordNew(list_options)
 		self.ddbb.insert("records",cells,values)
 		logging.debug('DB updated: '+str(cells)+' | '+str(values))
-		gpxOrig = self.conf.tmpdir+"/new_entry.gpx"
+		gpxOrig = list_options["rcd_gpxfile"]
 		if os.path.isfile(gpxOrig):
 			gpxDest = self.conf.getValue("gpxdir")
 			id_record = self.ddbb.lastRecord("records")
-			shutil.copy2(gpxOrig, gpxDest+"/%d.gpx"%id_record)
-			logging.debug('Moving '+gpxOrig+' to '+gpxDest+"/"+str(id_record))
+			gpxNew = gpxDest+"/%d.gpx"%id_record
+			shutil.move(gpxOrig, gpxNew)
+			logging.debug('Moving '+gpxOrig+' to '+gpxNew)
 		#self.parent.refreshListRecords()
 		logging.debug('<<')
 		return self.ddbb.lastRecord("records")
 		
-	def insertNewRecord(self, gpxOrig, entry):
+	def insertNewRecord(self, gpxOrig, entry): #TODO consolidate with insertRecord
 		"""29.03.2008 - dgranda
 		Moves GPX file to store destination and updates database
 		args: path to source GPX file"""
@@ -175,6 +185,8 @@ class Record:
 		logging.debug('>>')
 		gpx = Gpx(self.data_path,gpxOrig)
 		distance, time, maxspeed, maxheartrate = gpx.getMaxValues()
+		if time == 0: #invalid record
+			return None
 		upositive,unegative = gpx.getUnevenness()
 		speed = distance*3600/time
 		time_hhmmss = [time//3600,(time/60)%60,time%60]
@@ -182,13 +194,20 @@ class Record:
 		summaryRecord['rcd_gpxfile'] = gpxOrig
 		summaryRecord['rcd_sport'] = entry[0]
 		summaryRecord['rcd_date'] = gpx.getDate()
-		summaryRecord['rcd_calories'] = '0.0' # not supported yet (29.03.2008)
+		summaryRecord['rcd_calories'] = gpx.getCalories()
+		logging.debug('rcd_calories: ' + str(summaryRecord['rcd_calories']))
 		summaryRecord['rcd_comments'] = ''
 		summaryRecord['rcd_title'] = ''
 		summaryRecord['rcd_time'] = time_hhmmss #ToDo: makes no sense to work with arrays
 		summaryRecord['rcd_distance'] = "%0.2f" %distance 
-		summaryRecord['rcd_pace'] = "%d.%02d" %((3600/speed)/60,(3600/speed)%60)
-		summaryRecord['rcd_maxpace'] = "%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60)
+		if speed == 0:
+			summaryRecord['rcd_pace'] = 0
+		else:
+			summaryRecord['rcd_pace'] = "%d.%02d" %((3600/speed)/60,(3600/speed)%60)
+		if maxspeed == 0:
+			summaryRecord['rcd_maxpace'] = 0
+		else:
+			summaryRecord['rcd_maxpace'] = "%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60)
 		summaryRecord['rcd_average'] = speed
 		summaryRecord['rcd_maxvel'] = maxspeed
 		summaryRecord['rcd_beats'] = gpx.getHeartRateAverage()
@@ -196,9 +215,11 @@ class Record:
 		summaryRecord['rcd_upositive'] = upositive
 		summaryRecord['rcd_unegative'] = unegative
 		if entry[1]=="": # coming from new track dialog (file opening)
-			summaryRecord['date_time_utc'] = gpx.getStartTimeFromGPX(gpxOrig)
+			summaryRecord['date_time_utc'], summaryRecord['date_time_local'] = gpx.getStartTimeFromGPX(gpxOrig)
 		else: # coming from GPS device
 			summaryRecord['date_time_utc'] = entry[1]
+			summaryRecord['date_time_local'] = entry[1]
+			print "#TODO fix record summaryRecord local and utc time..."
 		logging.debug('summary: '+str(summaryRecord))
 		logging.debug('<<')
 		return summaryRecord
@@ -206,9 +227,9 @@ class Record:
 	def updateRecord(self, list_options, id_record):
 		logging.debug('>>')
 		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
-		if os.path.isfile(list_options["rcd_gpxfile"]):
-			if gpxfile != list_options["rcd_gpxfile"]:
-				gpxOrig = self.conf.tmpdir+"/newgpx.gpx"
+		gpxOrig = list_options["rcd_gpxfile"]
+		if os.path.isfile(gpxOrig):
+			if gpxfile != gpxOrig:
 				shutil.copy2(gpxOrig, gpxfile)
 		else:
 			if (list_options["rcd_gpxfile"]==""):
@@ -232,17 +253,27 @@ class Record:
 	def getrecordInfo(self,id_record):
 		logging.debug('--')
 		return self.ddbb.select("records,sports",
-					"sports.name,date,distance,time,beats,comments,average,calories,id_record,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats",
+					"sports.name,date,distance,time,beats,comments,average,calories,id_record,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local",
 					"id_record=\"%s\" and records.sport=sports.id_sports" %id_record)
 	
 	def getrecordList(self,date):
 		logging.debug('--')
 		return self.ddbb.select("records,sports",
-					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats",
+					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local",
 					"date=\"%s\" and records.sport=sports.id_sports" %date)
+
+	def getrecordPeriod(self,date_ini, date_end, sport=None):
+		#TODO This is essentially the same as getrecordPeriodSport (except date ranges) - need to look at merging the two
+		tables = "records,sports"
+		if not sport:
+			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports" %(date_ini,date_end)
+		else:
+			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports and sports.name=\"%s\"" %(date_ini,date_end, sport)
+	
+		return self.ddbb.select(tables,"date,distance,time,beats,comments,average,calories,maxspeed,maxbeats, sports.name", condition)
 	
 	def getrecordPeriodSport(self,date_ini, date_end,sport):
-		if sport<1 :
+		if not sport:
 			tables = "records"
 			condition = "date>\"%s\" and date<\"%s\"" %(date_ini,date_end)
 		else :
@@ -269,17 +300,19 @@ class Record:
 			add: attribute to add or not the sport to db
 		returns: id_sports from provided sport"""
 		logging.debug('>>')
-		sport_id=0
+		sport_id=1
+		if sport == "" or sport is None:
+			return sport_id
 		try:
 			sport_id = self.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
 		except:
 			logging.error('Error retrieving id_sports from '+ str(sport))
-			traceback.print_last()
+			#traceback.print_last()
 			if add is None:
 				logging.debug('Sport '+str(sport)+' will not be added to DB')
 			else:
 				logging.debug('Adding sport '+str(sport)+' to DB')
-				sport_id = self.addNewSport(self,sport,0,0)
+				sport_id = self.addNewSport(sport,"0","0")
 		logging.debug('<<')
 		return sport_id
 	
@@ -293,8 +326,8 @@ class Record:
 		returns: id_sports from new sport"""
 		logging.debug(">>")
 		logging.debug("Adding new sport: "+sport+"|"+weight+"|"+met)
-		sport = [sport,met,weight]
-		self.ddbb.insert("sports","name,met,weight",sport)
+		sportT = [sport,met,weight]
+		self.ddbb.insert("sports","name,met,weight",sportT)
 		sport_id = self.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
 		logging.debug("<<")
 		return sport_id
@@ -330,7 +363,7 @@ class Record:
 		logging.debug('<<')
 		return day_list
 		
-	def actualize_fromgpx(self,gpxfile):
+	def actualize_fromgpx(self,gpxfile): #TODO remove? - should never have multiple tracks per GPX file
 		logging.debug('>>')
 		logging.debug('loading file: '+gpxfile)
 		gpx = Gpx(self.data_path,gpxfile)
@@ -356,11 +389,13 @@ class Record:
 		upositive,unegative = gpx.getUnevenness()
 		heartrate = gpx.getHeartRateAverage()
 		date = gpx.getDate()
+		calories = gpx.getCalories()
 		
 		self.recordwindow.rcd_date.set_text(date)
 		self.recordwindow.rcd_upositive.set_text(str(upositive))
 		self.recordwindow.rcd_unegative.set_text(str(unegative))
 		self.recordwindow.rcd_beats.set_text(str(heartrate))
+		self.recordwindow.rcd_calories.set_text(str(calories))
 		self.recordwindow.set_distance(distance)
 		self.recordwindow.set_maxspeed(maxspeed)
 		self.recordwindow.set_maxhr(maxheartrate)
@@ -377,7 +412,7 @@ class Record:
 		self._actualize_fromgpx(gpx)
 		logging.debug('<<')
 
-	def _select_trkfromgpx(self,gpxfile,tracks):
+	def _select_trkfromgpx(self,gpxfile,tracks):  #TODO remove? - should never have multiple tracks per GPX file
 		logging.debug('>>')
 		logging.debug('Track dialog '+ self.data_path +'|'+ gpxfile)
 		selectrckdialog = DialogSelectTrack(self.data_path, tracks,self.__actualize_fromgpx, gpxfile)
@@ -385,7 +420,7 @@ class Record:
 		selectrckdialog.run()
 		logging.debug('<<')
 		
-	def newGpxRecord(self,gpxfile,list_sport):
+	def newGpxRecord(self,gpxfile,list_sport): #TODO Not used?
 		logging.debug('>>')
 		logging.debug("opening a new window record "+self.data_path+'|'+gpxfile+'|'+str(list_sport))
 		self.recordwindow = WindowRecord(self.data_path, list_sport,self, None)
@@ -397,13 +432,30 @@ class Record:
 		self.recordwindow.run()
 		logging.debug('<<')
 
-	def importFromGTRNCTR(self,gtrnctrFile):
+	def importFromGPX(self, gpxFile, sport):
+		"""
+		Add a record from a valid pytrainer type GPX file
+		"""	
+		logging.debug('>>')
+		logging.info('Retrieving data from '+gpxFile)
+		if not sport:
+			sport = "import"
+		entry = [sport,""]
+		entry_id = self.insertNewRecord(gpxFile, entry)
+		if entry_id is None:
+			logging.error("Entry not created for file %s" % gpxFile)
+		else:
+			logging.info("Entry %d has been added" % entry_id)
+		logging.debug('<<')
+
+	#def importFromGTRNCTR(self,gtrnctrFile): #TODO remove
 		"""22.03.2008 - dgranda
 		Retrieves sport, date and start time from each entry coming from GPS
 		and compares with what is stored locally, just to import new entries
 		31.08.2008 - dgranda - Only checks start time, discarding sport info
 		args: file with data from GPS file (garmin format)
 		returns: none"""
+		"""
 		logging.debug('>>')
 		logging.info('Retrieving data from '+gtrnctrFile)
 		xmlParser=XMLParser(gtrnctrFile)
@@ -426,14 +478,15 @@ class Record:
 		else:
 			logging.info('No tracks found in GPS device')
 		logging.debug('<<')
+		"""
 		
-	def shortFromLocal(self):
+	#def shortFromLocal(self): #TODO remove
 		"""25.03.2008 - dgranda
 		Retrieves sport, date and start time from each entry stored locally
 		12.07.2008 - dgranda - Added id_record for each one
 		returns: list with lists: SPORT|DATE_START_TIME|ID_RECORD
 		31.08.2008 - dgranda - Only available due to migration purposes from Main class"""
-		logging.debug('>>')
+		'''logging.debug('>>')
 		listTracksGPX = []
 		sport = "Run" #hardcoded - 25.03.2008 (no info stored in gpx files yet)
 		# looking in configuration for storing directory
@@ -442,7 +495,7 @@ class Record:
 		for gpxFile in os.listdir(gpxDir):
 			#logging.debug('File: '+gpxFile)
 			gpx = Gpx()
-			date_time = gpx.getStartTimeFromGPX(gpxDir+"/"+gpxFile)
+			date_time = gpx.getStartTimeFromGPX(gpxDir+"/"+gpxFile)[0]
 			if date_time != 0:
 				logging.debug('File: '+gpxFile+' | Date: '+date_time)
 				id_record = gpxFile.partition('.')[0]
@@ -450,13 +503,13 @@ class Record:
 			else:
 				logging.error('Skipping '+gpxFile+' because of wrong format')
 		logging.debug('<<')
-		return listTracksGPX
+		return listTracksGPX'''
 		
-	def shortFromLocalDB(self, getSport=True):
+	#def shortFromLocalDB(self, getSport=True): #TODO remove
 		"""12.07.2008 - dgranda
 		Retrieves sport, date and start time from local database
 		returns: list with lists: SPORT|DATE_START_TIME"""
-		logging.debug('>>')
+		'''logging.debug('>>')
 		# Retrieving sport (optional) and date_time (UTC) for each entry in DB
 		# ToDo: replace id_sports with name
 		listTracksGPX = self.ddbb.shortFromLocal(getSport)
@@ -471,21 +524,21 @@ class Record:
 			listTracksGPX = tempList
 		logging.debug('Retrieved info: '+str(listTracksGPX))
 		logging.debug('<<')
-		return listTracksGPX
+		return listTracksGPX'''
 		
-	def removeSportFromList(self, list1):
-		resultList = []
+	#def removeSportFromList(self, list1): #TODO remove
+		'''resultList = []
 		for entry in list1:
 			resultList.append(entry[1])
-		return resultList
+		return resultList'''
 		
-	def compareLists(self,list1,list2):
-		# Optimizing comparison - 26042008
-		# http://mail.python.org/pipermail/python-list/2002-May/142854.html
+	#def compareLists(self,list1,list2): #TODO remove
+		'''# Optimizing comparison - 26042008
+		# http://mail.python.org/pipermail/python-list/2002-May/141458.html
 		tempDict = dict(zip(list1,list1))
-		return [x for x in list2 if x not in tempDict]
+		return [x for x in list2 if x not in tempDict]'''
 		
-	def compareTracks(self,listTracksGPS,listTracksLocal,checkSport=True):
+	#def compareTracks(self,listTracksGPS,listTracksLocal,checkSport=True): #TODO remove
 		"""22.03.2008 - dgranda
 		Compares tracks retrieved from GPS with already locally stored
 		args:
@@ -493,7 +546,7 @@ class Record:
 			listTracksLocal: local track list with lists -> (SPORT)|DATE_START_TIME
 			checkSport (02.09.2008): indicates if sport data is included when comparing 
 		returns: tracks which are not present locally (list with lists)"""
-		logging.debug('>>')
+		'''logging.debug('>>')
 		if checkSport is True:
 			logging.info('Comparing sport info')
 			listGPS = listTracksGPS[:]
@@ -517,5 +570,5 @@ class Record:
 		logging.info('Tracks to be imported: '+str(len(resultList)))
 		logging.debug('Tracks summary: '+str(resultList))
 		logging.debug('<<')
-		return resultList
+		return resultList '''
 		
