@@ -20,40 +20,53 @@ from lib.ddbb import DDBB
 from lib.system import checkConf
 from lib.xmlUtils import XMLParser
 
+import logging
+
 class Waypoint:
 	def __init__(self, data_path = None, parent = None):
+		logging.debug(">>")
 		self.parent = parent
 		self.data_path = data_path
 		self.conf = checkConf()
 		self.filename = self.conf.getValue("conffile")
 		self.configuration = XMLParser(self.filename)
 		self.ddbb = DDBB(self.configuration)
+		logging.debug("<<")
 	
 	def removeWaypoint(self,id_waypoint):
+		logging.debug(">>")
 		self.ddbb.connect()
 		self.ddbb.delete("waypoints", "id_waypoint=\"%s\"" %id_waypoint)
 		self.ddbb.disconnect()
+		logging.debug("<<")
 
 	def updateWaypoint(self,id_waypoint,lat,lon,name,desc,sym):
+		logging.debug(">>")
 		self.ddbb.connect()
 		self.ddbb.update("waypoints","lat,lon,comment,name,sym",[lat,lon,desc,name,sym]," id_waypoint=%d" %id_waypoint)
 		self.ddbb.disconnect()
+		logging.debug("<<")
 
 	def getwaypointInfo(self,id_waypoint):
+		logging.debug(">>")
 		self.ddbb.connect()
 		retorno = self.ddbb.select("waypoint",
 					"lat,lon,ele,comment,time,name,sym"
 					"id_waypoint=\"%s\"" %id_waypoint)
 		self.ddbb.disconnect()
+		logging.debug("<<")
 		return retorno
 	
 	def getAllWaypoints(self):
+		logging.debug(">>")
 		self.ddbb.connect()
 		retorno = self.ddbb.select("waypoints","id_waypoint,lat,lon,ele,comment,time,name,sym","1=1 order by name")
 		self.ddbb.disconnect()
+		logging.debug("<<")
 		return retorno
 	
 	def actualize_fromgpx(self,gpxfile):
+		logging.debug(">>")
 		self.ddbb.connect()
 		from lib.gpx import Gpx
 		gpx = Gpx(self.data_path,gpxfile)
@@ -70,8 +83,10 @@ class Waypoint:
                         warning.set_text(msg)
                         warning.run()
 		self.ddbb.disconnect()
+		logging.debug("<<")
 
 	def _actualize_fromgpx(self, gpx):
+		logging.debug(">>")
 		distance, time = gpx.getMaxValues()
 		upositive,unegative = gpx.getUnevenness()
 		self.recordwindow.rcd_upositive.set_text(str(upositive))
@@ -79,4 +94,5 @@ class Waypoint:
 		self.recordwindow.set_distance(distance)
 		self.recordwindow.set_recordtime(time/60.0/60.0)
 		self.recordwindow.on_calcaverage_clicked(None)
+		logging.debug("<<")
 		
